==> python-unidecode-1.0.22-2-any.pkg.tar.xz: usr/lib/python3.7/site-packages/unidecode/x0fb.py <==
data = (
'ff',    # 0x00
'fi',    # 0x01
'fl',    # 0x02
'ffi',    # 0x03
'ffl',    # 0x04
'st',    # 0x05
'st',    # 0x06
'[?]',    # 0x07
'[?]',    # 0x08
'[?]',    # 0x09
'[?]',    # 0x0a
'[?]',    # 0x0b
'[?]',    # 0x0c
'[?]',    # 0x0d
'[?]',    # 0x0e
'[?]',    # 0x0f
'[?]',    # 0x10
'[?]',    # 0x11
'[?]',    # 0x12
'mn',    # 0x13
'me',    # 0x14
'mi',    # 0x15
'vn',    # 0x16
'mkh',    # 0x17
'[?]',    # 0x18
'[?]',    # 0x19
'[?]',    # 0x1a
'[?]',    # 0x1b
'[?]',    # 0x1c
'yi',    # 0x1d
'',    # 0x1e
'ay',    # 0x1f
'`',    # 0x20
'',    # 0x21
'd',    # 0x22
'h',    # 0x23
'k',    # 0x24
'l',    # 0x25
'm',    # 0x26
'm',    # 0x27
't',    # 0x28
'+',    # 0x29
'sh',    # 0x2a
's',    # 0x2b
'sh',    # 0x2c
's',    # 0x2d
'a',    # 0x2e
'a',    # 0x2f
'',    # 0x30
'b',    # 0x31
'g',    # 0x32
'd',    # 0x33
'h',    # 0x34
'v',    # 0x35
'z',    # 0x36
'[?]',    # 0x37
't',    # 0x38
'y',    # 0x39
'k',    # 0x3a
'k',    # 0x3b
'l',    # 0x3c
'[?]',    # 0x3d
'l',    # 0x3e
'[?]',    # 0x3f
'n',    # 0x40
'n',    # 0x41
'[?]',    # 0x42
'p',    # 0x43
'p',    # 0x44
'[?]',    # 0x45
'ts',    # 0x46
'ts',    # 0x47
'r',    # 0x48
'sh',    # 0x49
't',    # 0x4a
'vo',    # 0x4b
'b',    # 0x4c
'k',    # 0x4d
'p',    # 0x4e
'l',    # 0x4f
'',    # 0x50
'',    # 0x51
'',    # 0x52
'',    # 0x53
'',    # 0x54
'',    # 0x55
'',    # 0x56
'',    # 0x57
'',    # 0x58
'',    # 0x59
'',    # 0x5a
'',    # 0x5b
'',    # 0x5c
'',    # 0x5d
'',    # 0x5e
'',    # 0x5f
'',    # 0x60
'',    # 0x61
'',    # 0x62
'',    # 0x63
'',    # 0x64
'',    # 0x65
'',    # 0x66
'',    # 0x67
'',    # 0x68
'',    # 0x69
'',    # 0x6a
'',    # 0x6b
'',    # 0x6c
'',    # 0x6d
'',    # 0x6e
'',    # 0x6f
'',    # 0x70
'',    # 0x71
'',    # 0x72
'',    # 0x73
'',    # 0x74
'',    # 0x75
'',    # 0x76
'',    # 0x77
'',    # 0x78
'',    # 0x79
'',    # 0x7a
'',    # 0x7b
'',    # 0x7c
'',    # 0x7d
'',    # 0x7e
'',    # 0x7f
'',    # 0x80
'',    # 0x81
'',    # 0x82
'',    # 0x83
'',    # 0x84
'',    # 0x85
'',    # 0x86
'',    # 0x87
'',    # 0x88
'',    # 0x89
'',    # 0x8a
'',    # 0x8b
'',    # 0x8c
'',    # 0x8d
'',    # 0x8e
'',    # 0x8f
'',    # 0x90
'',    # 0x91
'',    # 0x92
'',    # 0x93
'',    # 0x94
'',    # 0x95
'',    # 0x96
'',    # 0x97
'',    # 0x98
'',    # 0x99
'',    # 0x9a
'',    # 0x9b
'',    # 0x9c
'',    # 0x9d
'',    # 0x9e
'',    # 0x9f
'',    # 0xa0
'',    # 0xa1
'',    # 0xa2
'',    # 0xa3
'',    # 0xa4
'',    # 0xa5
'',    # 0xa6
'',    # 0xa7
'',    # 0xa8
'',    # 0xa9
'',    # 0xaa
'',    # 0xab
'',    # 0xac
'',    # 0xad
'',    # 0xae
'',    # 0xaf
'',    # 0xb0
'',    # 0xb1
'[?]',    # 0xb2
'[?]',    # 0xb3
'[?]',    # 0xb4
'[?]',    # 0xb5
'[?]',    # 0xb6
'[?]',    # 0xb7
'[?]',    # 0xb8
'[?]',    # 0xb9
'[?]',    # 0xba
'[?]',    # 0xbb
'[?]',    # 0xbc
'[?]',    # 0xbd
'[?]',    # 0xbe
'[?]',    # 0xbf
'[?]',    # 0xc0
'[?]',    # 0xc1
'[?]',    # 0xc2
'[?]',    # 0xc3
'[?]',    # 0xc4
'[?]',    # 0xc5
'[?]',    # 0xc6
'[?]',    # 0xc7
'[?]',    # 0xc8
'[?]',    # 0xc9
'[?]',    # 0xca
'[?]',    # 0xcb
'[?]',    # 0xcc
'[?]',    # 0xcd
'[?]',    # 0xce
'[?]',    # 0xcf
'[?]',    # 0xd0
'[?]',    # 0xd1
'[?]',    # 0xd2
'',    # 0xd3
'',    # 0xd4
'',    # 0xd5
'',    # 0xd6
'',    # 0xd7
'',    # 0xd8
'',    # 0xd9
'',    # 0xda
'',    # 0xdb
'',    # 0xdc
'',    # 0xdd
'',    # 0xde
'',    # 0xdf
'',    # 0xe0
'',    # 0xe1
'',    # 0xe2
'',    # 0xe3
'',    # 0xe4
'',    # 0xe5
'',    # 0xe6
'',    # 0xe7
'',    # 0xe8
'',    # 0xe9
'',    # 0xea
'',    # 0xeb
'',    # 0xec
'',    # 0xed
'',    # 0xee
'',    # 0xef
'',    # 0xf0
'',    # 0xf1
'',    # 0xf2
'',    # 0xf3
'',    # 0xf4
'',    # 0xf5
'',    # 0xf6
'',    # 0xf7
'',    # 0xf8
'',    # 0xf9
'',    # 0xfa
'',    # 0xfb
'',    # 0xfc
'',    # 0xfd
'',    # 0xfe
'',    # 0xff
)

==> python-unidecode-1.4.0-1-any.pkg.tar.xz: usr/lib/python3.13/site-packages/unidecode/x0fb.py <==
data = (
'ff',    # 0x00
'fi',    # 0x01
'fl',    # 0x02
'ffi',    # 0x03
'ffl',    # 0x04
'st',    # 0x05
'st',    # 0x06
None,    # 0x07
None,    # 0x08
None,    # 0x09
None,    # 0x0a
None,    # 0x0b
None,    # 0x0c
None,    # 0x0d
None,    # 0x0e
None,    # 0x0f
None,    # 0x10
None,    # 0x11
None,    # 0x12
'mn',    # 0x13
'me',    # 0x14
'mi',    # 0x15
'vn',    # 0x16
'mkh',    # 0x17
None,    # 0x18
None,    # 0x19
None,    # 0x1a
None,    # 0x1b
None,    # 0x1c
'i',    # 0x1d
'',    # 0x1e
'AY',    # 0x1f
'`',    # 0x20
'A',    # 0x21
'd',    # 0x22
'h',    # 0x23
'KH',    # 0x24
'l',    # 0x25
'm',    # 0x26
'r',    # 0x27
't',    # 0x28
'+',    # 0x29
'SH',    # 0x2a
'S',    # 0x2b
'SH',    # 0x2c
'S',    # 0x2d
'a',    # 0x2e
'a',    # 0x2f
'A',    # 0x30
'b',    # 0x31
'g',    # 0x32
'd',    # 0x33
'h',    # 0x34
'v',    # 0x35
'z',    # 0x36
None,    # 0x37
't',    # 0x38
'y',    # 0x39
'KH',    # 0x3a
'KH',    # 0x3b
'l',    # 0x3c
None,    # 0x3d
'm',    # 0x3e
None,    # 0x3f
'n',    # 0x40
's',    # 0x41
None,    # 0x42
'p',    # 0x43
'p',    # 0x44
None,    # 0x45
'TS',    # 0x46
'k',    # 0x47
'r',    # 0x48
'SH',    # 0x49
't',    # 0x4a
'o',    # 0x4b
'v',    # 0x4c
'KH',    # 0x4d
'f',    # 0x4e
'EL',    # 0x4f
'',    # 0x50
'',    # 0x51
'',    # 0x52
'',    # 0x53
'',    # 0x54
'',    # 0x55
'',    # 0x56
'',    # 0x57
'',    # 0x58
'',    # 0x59
'',    # 0x5a
'',    # 0x5b
'',    # 0x5c
'',    # 0x5d
'',    # 0x5e
'',    # 0x5f
'',    # 0x60
'',    # 0x61
'',    # 0x62
'',    # 0x63
'',    # 0x64
'',    # 0x65
'',    # 0x66
'',    # 0x67
'',    # 0x68
'',    # 0x69
'',    # 0x6a
'',    # 0x6b
'',    # 0x6c
'',    # 0x6d
'',    # 0x6e
'',    # 0x6f
'',    # 0x70
'',    # 0x71
'',    # 0x72
'',    # 0x73
'',    # 0x74
'',    # 0x75
'',    # 0x76
'',    # 0x77
'',    # 0x78
'',    # 0x79
'',    # 0x7a
'',    # 0x7b
'',    # 0x7c
'',    # 0x7d
'',    # 0x7e
'',    # 0x7f
'',    # 0x80
'',    # 0x81
'',    # 0x82
'',    # 0x83
'',    # 0x84
'',    # 0x85
'',    # 0x86
'',    # 0x87
'',    # 0x88
'',    # 0x89
'',    # 0x8a
'',    # 0x8b
'',    # 0x8c
'',    # 0x8d
'',    # 0x8e
'',    # 0x8f
'',    # 0x90
'',    # 0x91
'',    # 0x92
'',    # 0x93
'',    # 0x94
'',    # 0x95
'',    # 0x96
'',    # 0x97
'',    # 0x98
'',    # 0x99
'',    # 0x9a
'',    # 0x9b
'',    # 0x9c
'',    # 0x9d
'',    # 0x9e
'',    # 0x9f
'',    # 0xa0
'',    # 0xa1
'',    # 0xa2
'',    # 0xa3
'',    # 0xa4
'',    # 0xa5
'',    # 0xa6
'',    # 0xa7
'',    # 0xa8
'',    # 0xa9
'',    # 0xaa
'',    # 0xab
'',    # 0xac
'',    # 0xad
'',    # 0xae
'',    # 0xaf
'',    # 0xb0
'',    # 0xb1
None,    # 0xb2
None,    # 0xb3
None,    # 0xb4
None,    # 0xb5
None,    # 0xb6
None,    # 0xb7
None,    # 0xb8
None,    # 0xb9
None,    # 0xba
None,    # 0xbb
None,    # 0xbc
None,    # 0xbd
None,    # 0xbe
None,    # 0xbf
None,    # 0xc0
None,    # 0xc1
None,    # 0xc2
None,    # 0xc3
None,    # 0xc4
None,    # 0xc5
None,    # 0xc6
None,    # 0xc7
None,    # 0xc8
None,    # 0xc9
None,    # 0xca
None,    # 0xcb
None,    # 0xcc
None,    # 0xcd
None,    # 0xce
None,    # 0xcf
None,    # 0xd0
None,    # 0xd1
None,    # 0xd2
'',    # 0xd3
'',    # 0xd4
'',    # 0xd5
'',    # 0xd6
'',    # 0xd7
'',    # 0xd8
'',    # 0xd9
'',    # 0xda
'',    # 0xdb
'',    # 0xdc
'',    # 0xdd
'',    # 0xde
'',    # 0xdf
'',    # 0xe0
'',    # 0xe1
'',    # 0xe2
'',    # 0xe3
'',    # 0xe4
'',    # 0xe5
'',    # 0xe6
'',    # 0xe7
'',    # 0xe8
'',    # 0xe9
'',    # 0xea
'',    # 0xeb
'',    # 0xec
'',    # 0xed
'',    # 0xee
'',    # 0xef
'',    # 0xf0
'',    # 0xf1
'',    # 0xf2
'',    # 0xf3
'',    # 0xf4
'',    # 0xf5
'',    # 0xf6
'',    # 0xf7
'',    # 0xf8
'',    # 0xf9
'',    # 0xfa
'',    # 0xfb
'',    # 0xfc
'',    # 0xfd
'',    # 0xfe
'',    # 0xff
)
